==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/inc/profile.tpl.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<?php
if (isset($recommendations)) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_recommending'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
			foreach($recommendations as $key => $i):
			?>
			<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
			<?php
			endforeach;
			?>
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
<?php }?>

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_subjects'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>					
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_comments'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
				if (isset($comments)) {
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
				<?php
				foreach ($comments as $key => $i):
				?>
				<tr>
					<td valign="top">
						<span class="comment_author">
							<b><?php echo $lang['txt_dated'];?></b> -&#62; 
							<?php echo $this->date->formatDate($i['comment_create_datetime'], 1);?><br />
							<b><?php echo $lang['txt_from'];?></b> -&#62;
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $i['identity_nic'];?></a>, 
							<?php echo $lang['txt_joined'] . ": " . $this->date->formatDate($i['participation_create_datetime']);?>, 
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ": " . $i['location_name'];
							}
							?><br />
						</span>
						
						<span id="comment_body_id_<?php echo $i['comment_id'];?>">
							<?php echo $i['comment_body'];?><br />
						</span>
					</td>
					<td valign="top" align="right">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['item_id'];?>&amp;subject_id=<?php echo $i['inner_item_id'];?>#comment_body_id_<?php echo $i['comment_id'];?>">
						<img src="<?php echo $template_path;?>img/discuss.png" alt="<?php echo $lang['txt_discuss'];?>" border="0" title="<?php echo $lang['txt_discuss'];?>" /></a><br />				
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php }?>
		</div>
	</div>
</div>
	
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>

==> am_mod_grp_0_5.zip: am_mod_grp_0_5/components/grp/template/barnraiser_01/inc/profile.tpl.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<?php
if (isset($recommendations)) {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_recommending'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
			foreach($recommendations as $key => $i):
			?>
			<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
			<?php
			endforeach;
			?>
		</div>
	</div>
</div>
<?php }?>

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_subjects'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>					
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
		</div>
	</div>
</div>

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_comments'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
			if (isset($comments)) {
			?>
			<table cellspacing="1" cellpadding="4" border="0" width="100%">
				<?php
				foreach ($comments as $key => $i):
				?>
				<tr>
					<td valign="top">
						<span class="comment_author">
							<b><?php echo $lang['txt_dated'];?></b> -&#62; 
							<?php echo $this->date->formatDate($i['comment_create_datetime'], 1);?><br />
							<b><?php echo $lang['txt_from'];?></b> -&#62;
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $i['identity_nic'];?></a>, 
							<?php echo $lang['txt_joined'] . ": " . $this->date->formatDate($i['participation_create_datetime']);?>, 
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ": " . $i['location_name'];
							}
							?><br />
						</span>
						
						<span id="comment_body_id_<?php echo $i['comment_id'];?>">
							<?php echo $i['comment_body'];?><br />
						</span>
					</td>
					<td valign="top" align="right">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['item_id'];?>&amp;subject_id=<?php echo $i['inner_item_id'];?>#comment_body_id_<?php echo $i['comment_id'];?>">
						<img src="<?php echo $template_path;?>img/discuss.png" alt="<?php echo $lang['txt_discuss'];?>" border="0" title="<?php echo $lang['txt_discuss'];?>" /></a><br />				
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php
			} else {
			?>
				<p>
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</p>
			<?php }?>
		</div>
	</div>
</div>
